aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--cryptography/hazmat/primitives/interfaces.py10
1 files changed, 6 insertions, 4 deletions
diff --git a/cryptography/hazmat/primitives/interfaces.py b/cryptography/hazmat/primitives/interfaces.py
index 4d9e7879..04537f8c 100644
--- a/cryptography/hazmat/primitives/interfaces.py
+++ b/cryptography/hazmat/primitives/interfaces.py
@@ -295,9 +295,10 @@ class DSAParams(six.with_metaclass(abc.ABCMeta)):
"""
@abc.abstractproperty
- def divisor(self):
+ def subgroup_order(self):
"""
- The prime divisor of (p-1) that's used in generating the DSA keypair.
+ The subgroup order that's used in generating the DSA keypair
+ by the generator.
"""
@abc.abstractproperty
@@ -322,8 +323,9 @@ class DSAParams(six.with_metaclass(abc.ABCMeta)):
@abc.abstractproperty
def q(self):
"""
- The prime divisor of (p-1) that's used in generating the DSA keypair.
- Alias for divisor.
+ The subgroup order that's used in generating the DSA keypair
+ by the generator.
+ Alias for subgroup_order.
"""
@abc.abstractproperty